/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOUSE. See the GNU
 * General Public License for more details.
 *
 * You should have recieved a copy of the GNU General Public License
 * along with this program; if not write to the Free Software
 * Foundation, inc., 59 Temple Place, Suite 330, Boston MA 02111-1307
 * USA
 */
package JavaMicroBenchmark;

import java.util.*;

/**
 * 
 * Java Micro Benchmark created a microbenchmark to test the performance of Java operations
 * on different platforms. Java Micro Benchmark can be used to guide optimization decisions
 * and to compare different Java implementations. 
 *
 * @author: Yuriy Mikhaylovskiy  YuriyMikhaylovskiy@yahoo.com
 *  
 * 
 */
public class JavaMicroBenchmarkDesktop {

    private int number_of_count = 1000000000;
    public String result_string = "";
    public double result_mflops = 0;

    public JavaMicroBenchmarkDesktop() {
    }

    public String solve() {
        String st_res = "";
        double speed = 0;
        result_mflops = 0;
        JavaMicroBenchmark bm = new JavaMicroBenchmark();
        JavaMicroBenchmarkHDD bm_HDD = new JavaMicroBenchmarkHDD();
        double res = bm.solve(number_of_count);
        double res_HDD = bm_HDD.solve(number_of_count / 2);
        result_mflops = (res + res_HDD) / 2.0f;
        result_string = bm.result_string + "\n" + bm_HDD.result_string;
        result_string += "\nDesktop: Index of overall performance: " + result_mflops;
        System.out.println("\nDesktop: Index of overall performance: " + result_mflops);
        return result_string;
    }

    public double solve(int cnt) {
        number_of_count = cnt;
        solve();
        return result_mflops;
    }

    public String SystemInfo() {
        String st_res = "";
        try {
            Hashtable env = new Hashtable(System.getenv());
            for (Enumeration e = env.keys(); e.hasMoreElements();) {
                Object key = e.nextElement();
                System.out.println(key + ": " + env.get(key));
                st_res += key + ": " + env.get(key) + "\n";
            }
        } catch (Exception e) {
            System.out.println(e);
        }
        try {
            Properties prop = System.getProperties();
            for (Enumeration e = prop.keys(); e.hasMoreElements();) {
                Object key = e.nextElement();
                System.out.println(key + ": " + prop.get(key));
                st_res += key + ": " + prop.get(key) + "\n";
            }
        } catch (Exception e) {
            System.out.println(e);
        }
        return st_res;
    }

    public static void main(String[] args) {
        new JavaMicroBenchmarkDesktop().solve(1000000000);
    }
}
