/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOUSE. See the GNU
 * General Public License for more details.
 *
 * You should have recieved a copy of the GNU General Public License
 * along with this program; if not write to the Free Software
 * Foundation, inc., 59 Temple Place, Suite 330, Boston MA 02111-1307
 * USA
 */
package JavaMicroBenchmark;

import java.util.*;

/**
 *
 * Java Micro Benchmark created a microbenchmark to test the performance of Java operations
 * on different platforms. Java Micro Benchmark can be used to guide optimization decisions
 * and to compare different Java implementations.
 *
 * @author: Yuriy Mikhaylovskiy  YuriyMikhaylovskiy@yahoo.com
 *
 *
 */

public class JavaMicroBenchmarkHDD {

    private int number_of_processors = 1;
    private int number_of_count = 1000000000;
    private JavaMicroBenchmarkResult[][] mbmo;
    public String result_string = "";
    public double result_mflops = 0;

    public JavaMicroBenchmarkHDD() {
    }

    public String solve() {
        String st_res = "";
        double speed = 0;
        result_mflops = 0;
        while (result_mflops == 0 || Double.isInfinite(result_mflops)) {
            st_res = "";
            //st_res += SystemInfo()+"\n\n";
            Runtime rt = Runtime.getRuntime();
            rt.gc();
            number_of_processors = rt.availableProcessors();
            System.out.print("\nNumber of processors / threads:  " + number_of_processors + " / " + number_of_processors);
            st_res += "\nNumber of processors / threads:  " + number_of_processors + " / " + number_of_processors + "\n";
            System.out.println("\n*** Start Java Micro Benchmark HDD ***");
            st_res += "\n*** Start Java Micro Benchmark HDD ***\n";
            Thread[] t = new Thread[number_of_processors];
            mbmo = new JavaMicroBenchmarkResult[3][number_of_processors];
            for (int i = 0; i < number_of_processors; i++) {
                try {
                    t[i] = new Thread("" + i) {

                        public void run() {
                            int j = Integer.parseInt(this.getName());
                            JavaMicroBenchmarkCreateFile mbmcf = new JavaMicroBenchmarkCreateFile();
                            mbmcf.count = number_of_count/100000;
                            mbmcf.solve();
                            mbmo[0][j] = (JavaMicroBenchmarkResult) mbmcf;
                            JavaMicroBenchmarkWriteFile mbmwf = new JavaMicroBenchmarkWriteFile();
                            mbmwf.count = number_of_count/2000;
                            mbmwf.solve();
                            mbmo[1][j] = (JavaMicroBenchmarkResult) mbmwf;
                            JavaMicroBenchmarkReadFile mbmrf = new JavaMicroBenchmarkReadFile();
                            mbmrf.count = number_of_count/2000;
                            mbmrf.solve();
                            mbmo[2][j] = (JavaMicroBenchmarkResult) mbmrf;
                        }
                    };
                } catch (Exception e) {
                    System.out.println(e);
                }
            }
            for (int i = 0; i < number_of_processors; i++) {
                t[i].start();
            }
            try {
                for (int i = 0; i < number_of_processors; i++) {
                    t[i].join();
                }
            } catch (Exception e) {
                System.out.println(e);
            }
            double s = 0;
            speed = 0;
            for (int i = 0; i < number_of_processors; i++) {
                for (int j = 0; j < mbmo.length; j++) {
                    s += mbmo[j][i].resultTime;
                    speed += mbmo[j][i].resultSpeed;
                    System.out.println("Thread (" + i + ") " + mbmo[j][i].resultInfo);
                    st_res += "Thread (" + i + ") " + mbmo[j][i].resultInfo + "\n";
                }
            }
            speed /= mbmo.length;//*number_of_processors;
            speed /= 10.0f;
            System.out.println("\nTime: " + s + " ms");
            st_res += "\nTime, ms: " + s + " ms\n";
            System.out.println("HDD: Index of overall performance: " + speed);
            st_res += "HDD: Index of overall performance: " + speed + "\n";
            System.out.println("*** End Java Micro Benchmark HDD ***\n");
            st_res += "*** End Java Micro Benchmark HDD ***\n\n";
            result_string = st_res;
            result_mflops = speed;
        }
        return st_res;
    }

    public double solve(int cnt) {
        number_of_count = cnt;
        solve();
        return result_mflops;
    }

    public String SystemInfo() {
        String st_res = "";
        try {
            Hashtable env = new Hashtable(System.getenv());
            for (Enumeration e = env.keys(); e.hasMoreElements();) {
                Object key = e.nextElement();
                System.out.println(key + ": " + env.get(key));
                st_res += key + ": " + env.get(key) + "\n";
            }
        } catch (Exception e) {
            System.out.println(e);
        }
        try {
            Properties prop = System.getProperties();
            for (Enumeration e = prop.keys(); e.hasMoreElements();) {
                Object key = e.nextElement();
                System.out.println(key + ": " + prop.get(key));
                st_res += key + ": " + prop.get(key) + "\n";
            }
        } catch (Exception e) {
            System.out.println(e);
        }
        return st_res;
    }

    public static void main(String[] args) {
        new JavaMicroBenchmarkHDD().solve();
    }
}
