/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOUSE. See the GNU
 * General Public License for more details.
 *
 * You should have recieved a copy of the GNU General Public License
 * along with this program; if not write to the Free Software
 * Foundation, inc., 59 Temple Place, Suite 330, Boston MA 02111-1307
 * USA
 */

package JavaMicroBenchmark;

import java.io.*;

/**
 *
 * Java Micro Benchmark created a microbenchmark to test the performance of Java operations
 * on different platforms. Java Micro Benchmark can be used to guide optimization decisions
 * and to compare different Java implementations.
 *
 * @author: Yuriy Mikhaylovskiy  YuriyMikhaylovskiy@yahoo.com
 *
 *
 */


public class JavaMicroBenchmarkWriteFile extends JavaMicroBenchmarkResult{
        public int count = 500000;
		
	public void solve(int cnt){
            try{
                File f = File.createTempFile("JavaMicroBenchmark_", null);
                f.deleteOnExit();
                FileOutputStream fw = new FileOutputStream(f);
                byte[] b = new byte[1024];
                for(int i=0; i<b.length; i++) b[i]=0;
                long startTime = System.currentTimeMillis();
                for(int i=0; i<cnt; i++){
                    fw.write(b);
                }
                fw.flush();
                resultTime = System.currentTimeMillis() - startTime;
                resultSpeed = (cnt*1.0f/(resultTime/1000.0f)/1024);
                resultInfo = "Write Mega Bytes per second: "+resultSpeed;
                fw.close();
                f.delete();
            }catch(Exception e) {
                resultTime = 0;
                resultSpeed = 0;
                resultInfo = "Error write bytes!";
            }
	}

        public void solve(){
            solve(count);
	}
		

	public static void main(String[] args)	{
            JavaMicroBenchmarkWriteFile mbm = new JavaMicroBenchmarkWriteFile();
            mbm.solve();
            System.out.println(mbm.resultInfo);
	}
}
